/**
 * Checker to compare output and answer in the form:
 *
 * Case 1: <number>
 * Case 2: <number>
 * ...
 * Case n: <number>
 *
 */

#include "testlib.h"

#include <iostream>
#include <sstream>
#include <fstream>
#include <iomanip>
#include <string>
#include <cstdlib>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <ctime>
#include <climits>
#include <cassert>
#include <vector>
#include <queue>
#include <stack>
#include <deque>
#include <set>
#include <map>
#include <bitset>
#include <utility>
#include <algorithm>

using namespace std;

#define forn(i, n) for (int i = 0; i < int(n); i++)

const double EPS = 1E-4;

vector<double> readStream(InStream& in, TResult pe)
{
    vector<double> result;

    for (int testCase = 1; !in.seekEof(); testCase++)
    {
        string caseStr = in.readToken();
        if (caseStr != "Case")
            quitf(pe, "Expected 'Case' but found '%s' [test case %d]", compress(caseStr).c_str(), testCase);

        string numExpStr;
        stringstream ss;
        ss << "#" << testCase;
        ss >> numExpStr;
        numExpStr += ":";
        string numStr = in.readToken();
        if (numExpStr != numStr)
            quitf(pe, "Expected '%s' but found '%s' [test case %d]", compress(numExpStr).c_str(), compress(numStr).c_str(), testCase);

        result.push_back(in.readDouble());
    }

    return result;
}

int main(int argc, char* argv[])
{
    setName("Single real numbers checker with testcase-support");
    registerTestlibCmd(argc, argv);

    vector<double> ja = readStream(ans, _fail);
    vector<double> pa = readStream(ouf, _pe);

    forn(i, min(ja.size(), pa.size()))
     {
        if (isnan(pa[i])) 
         quitf (_wa,"%d%s number: NAN found",i+1,englishEnding(i+1).c_str());
        if (isnan(ja[i])) 
         quitf (_fail,"%d%s number: NAN found",i+1,englishEnding(i+1).c_str());
        if (isinf(pa[i])) 
         quitf (_wa,"%d%s number: INFINITY found",i+1,englishEnding(i+1).c_str());
        if (isinf(ja[i])) 
         quitf (_fail,"%d%s number: INFINITY found",i+1,englishEnding(i+1).c_str());


    if (fabs(ja[i] - pa[i]) > EPS + 1E-15)
        quitf(_wa, "expected %.10lf, found %.10lf [test case %d]", ja[i],pa[i], i+1);
     }
    
    if (ja.size() != pa.size())
        quitf(_pe, "Expected %d test case(s) but found %d", ja.size(), pa.size());

    quitf(_ok, "%d cases", ja.size());
}
