#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;
typedef long double lf;

#define sz(x) ((int) (x).size())
#define pb push_back
#define mp make_pair
#define fi first
#define se second

#define NAME "e"

struct pt
{
	ld x, y;
	
	explicit pt(ld nx = 0, ld ny = 0): x(nx), y(ny) {}
	
	pt operator + (const pt &p) const
	{
		return pt(x + p.x, y + p.y);
	}
	
	pt operator - (const pt &p) const
	{
		return pt(x - p.x, y - p.y);
	}
	
	ld operator % (const pt &p) const
	{
		return x * p.y - y * p.x;
	}
	
	pt operator / (const ld k) const
	{
		return pt(x / k, y / k);
	}
	
	pt operator * (const ld k) const
	{
		return pt(x * k, y * k);
	}
	
	ld sqlen() const
	{
		return x * x + y * y;
	}
};

ld len(pt p)
{
	return sqrtl(p.sqlen());
}

const int maxn = 2000;
const lf eps_belong = 1e-8;
const lf eps_vp = 1e-10;
const lf eps_sq = 1e-10;

int n, m;
int theta, R;
pt cur, speed, dir;
int dir_turn, speed_turn;
pt pts[maxn];
bool killed[maxn];
int curtime;

const lf pi = acosl(-1.0);

ld radians(ld ang)
{
	return ang / 180.0 * pi;
}

pt rotate(pt p, ld ang)
{
	return pt(p.x * cosl(ang) - p.y * sinl(ang),
			  p.x * sinl(ang) + p.y * cosl(ang));
}

int vect_sign(pt v, pt dir, ld rot)
{
	dir = rotate(dir, radians(fmodl(rot, 360.0)));
	ld value = v.x * dir.y - v.y * dir.x;
	if (fabsl(value) < eps_vp)
		return 0;
	return value < 0 ? -1 : 1;
}

int cross_sign(pt v, pt dir, ld rot)
{
	dir = rotate(dir, radians(fmodl(rot, 360.0)));
	ld value = v.x * dir.x + v.y * dir.y;
	if (fabsl(value) < eps_vp)
		return 0;
	return value < 0 ? -1 : 1;
}

ld sq(pt a, pt b, pt c)
{
	return fabsl((a - b) % (c - b));
}

void check_par(pt a, pt d, pt side, ld rot)
{
	side = rotate(side, radians(fmodl(rot, 360.0)));
	pt b = a + side, c = d + side;
	for (int i = 0; i < n; ++i)
	{
		ld s = sq(pts[i], a, b) + sq(pts[i], b, c) + sq(pts[i], c, d) + sq(pts[i], d, a);
		ld need = sq(a, b, c) + sq(a, c, d);
		if (fabsl(s - need) < eps_sq)
			killed[i] = true;
	}
}

bool check_clock(pt o, pt dir, ld ang1, ld ang2, pt p)
{
	assert(ang2 - ang1 <= 180);
	pt op = p - o;
	if (op.sqlen() > R * R + eps_belong)
		return false;
	return vect_sign(op, dir, ang1) <= 0 &&
		   vect_sign(op, dir, ang2) >= 0;
}

void check_all()
{
	for (int i = 0; i < n; ++i)
	{
		if (check_clock(cur, dir, (ld) dir_turn - (ld) theta / 2.0, 
								  (ld) dir_turn + (ld) theta / 2.0, pts[i]))
			killed[i] = true;
	}
}

void waitTime(int t)
{
	pt nspeed = speed / len(speed);
	pt ncur = cur + nspeed * t;
	check_par(cur, ncur, dir, (ld) dir_turn - theta / 2.0);
	check_par(cur, ncur, dir, (ld) dir_turn + theta / 2.0);
	if (cross_sign(speed, dir, dir_turn + theta / 2.0) * 
		cross_sign(speed, dir, dir_turn - theta / 2.0) == -1)
	{
		check_par(cur, ncur, dir, dir_turn);
	}
	cur = ncur;
	check_all();
}

void turnHead(int ang)
{
	for (int i = 0; i < n; ++i)
	{
		if (check_clock(cur, dir, dir_turn, dir_turn + ang, pts[i]))
			killed[i] = true;
	}
	dir_turn = (dir_turn + ang) % 360;
	check_all();
}

void turnSpeed(int ang)
{
	speed_turn = (speed_turn + ang) % 360;
}

void solve(int t)
{
	cin >> n >> m >> R >> theta;
	cin >> cur.x >> cur.y;
	cin >> speed.x >> speed.y;
	cin >> dir.x >> dir.y;
	fill(killed, killed + n, false);
	dir_turn = speed_turn = 0;
	curtime = 0;
	for (int i = 0; i < n; ++i)
		cin >> pts[i].x >> pts[i].y;
	check_all();
	for (int i = 0; i < m; ++i)
	{
		int p, t, ang;
		cin >> p >> t >> ang;
		waitTime(t - curtime);
		if (p == 1)
			turnHead(ang);
		else
			turnSpeed(ang);
		curtime = t;
	}
	printf("Case #%d: ", t);
	for (int i = 0; i < n; ++i)
		printf("%c", killed[i] ? '0' : '1');
	printf("\n");
}

int main()
{
	#ifdef LOCAL
	assert(freopen(NAME ".in", "r", stdin));
	#endif // LOCAL
	int t;
	scanf("%d", &t);
	for (int i = 1; i <= t; ++i)
		solve(i);
	#ifdef LOCAL
	cerr << "Time: " << double(clock()) / CLOCKS_PER_SEC << "\n";
	#endif // LOCAL
	return 0;
}
