#include <iostream>
#include <vector>
#include <algorithm>
#include <string>

using namespace std;

typedef unsigned int uint;

uint GetBit(uint mask, int pos)
{
    return (mask >> pos) & 1;
}

const int max_n = 3e4;

struct Node
{
    int next[2];
    bool flag;
    bool r_flag;
};

Node mem[100 * max_n];
int mem_size;

void ClearNode(int v)
{
    mem[v].next[0] = mem[v].next[1] = -1;
    mem[v].flag = false;
    mem[v].r_flag = false;
}

void ClearMem()
{
    mem_size = 1;
    ClearNode(0);
}

int GetNode()
{
    ClearNode(mem_size);
    ++mem_size;
    return mem_size - 1;
}

void AddToTrie(uint ip, int l)
{
    int indx = 0;
    for (int i = 0; i < l; ++i) {
        uint b = GetBit(ip, i);

        if (mem[indx].next[b] == -1) {
            mem[indx].next[b] = GetNode();
        }

        indx = mem[indx].next[b];
    }

    mem[indx].flag = true;
}

void ConstructFlags(int indx)
{
    mem[indx].r_flag = mem[indx].flag;
    for (int b = 0; b < 2; ++b) {
        if (mem[indx].next[b] != -1) {
            int n_indx = mem[indx].next[b];
            ConstructFlags(n_indx);
            mem[indx].r_flag |= mem[n_indx].r_flag;
        }
    }
}

int GetNumber(const string& s, int l, int r)
{
    int result = 0;
    for (int i = l; i <= r; ++i) {
        result = result * 10 + (s[i] - '0');
    }

    return result;
}

uint Rev(uint x)
{
    uint result = 0;
    for (int i = 0; i < 8; ++i) {
        result += (1 << (7 - i)) * GetBit(x, i);
    }
    return result;
}

uint GetIp(const string& s, int l, int r)
{
    uint result = 0;

    int last_pos = r + 1;
    for (int i = r; i >= l; --i) {
        if (s[i] == '.') {
            result = (result << 8) + Rev(GetNumber(s, i + 1, last_pos - 1));
            last_pos = i;
        }
    }

    result = (result << 8) + Rev(GetNumber(s, l, last_pos - 1));

    return result;
}

void ShowMask(uint mask)
{
    for (int i = 0; i < 4; ++i) {
        cout << Rev((mask >> (8 * i)) & 255);
        if (i != 3) {
            cout << ".";
        }
    }
}

int ans_amount;

void ConstructAnswer(int indx, uint ip, int l, bool need_output)
{
    if (mem[indx].flag) {
        return ;
    }

    if (!mem[indx].r_flag) {
        ++ans_amount;
        if (need_output) {
            ShowMask(ip);
            cout << "/" << l << endl;
        }
    } else {
        for (int b = 0; b < 2; ++b) {
            if (mem[indx].next[b] == -1) {
                mem[indx].next[b] = GetNode();
            }
            ConstructAnswer(mem[indx].next[b], ip + b * (1 << l), l + 1, need_output);
        }
    }
}

int main() {
    ios_base::sync_with_stdio(false);

    int tests;
    cin >> tests;
    for (int test = 1; test <= tests; ++test) {
        ClearMem();

        int n;
        cin >> n;

        for (int i = 0; i < n; ++i) {
            string s;
            cin >> s;

            int p = s.find('/');

            uint ip = GetIp(s, 0, p - 1);

            int l = GetNumber(s, p + 1, s.length() - 1);

            AddToTrie(ip, l);
        }

        ConstructFlags(0);

        ans_amount = 0;
        ConstructAnswer(0, 0, 0, false);

        cout << "Case #" << test << ":" << endl;

        cout << ans_amount << endl;
        ConstructAnswer(0, 0, 0, true);
    }

    return 0;
}
