#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <ctime>
#include <cstring>
#include <algorithm>
#include <iostream>
#include <set>
#include <map>
#include <vector>
#include <queue>
#include <deque>
using namespace std;
#define pb push_back
#define mp make_pair
#define sc second
#define fs first
#define int64 long long
#define ldb long double
#define sz(a) ((int) (a).size())
#define eprintf(...) fprintf(stderr, __VA_ARGS__)

const int size = 150;
const double eps = 1e-9;
const double eps2 = 1e-7;

struct edge {
	int tg, back;
	double cap, flow;

	edge(int tg_ = 0, double cap_ = 0.0, double flow_ = 0.0, int back_ = 0) : tg(tg_), cap(cap_), flow(flow_), back(back_) {}
};

int tc;
int n, p[size];
int deg[size];
vector <edge> vertex[size];

int str, fin;
int sumdeg;

void addedge(int v, int u, int c1, int c2) {
	edge e1(u, c1, 0, vertex[u].size());
	edge e2(v, c2, 0, vertex[v].size());

	vertex[v].pb(e1);
	vertex[u].pb(e2);
}

int hg[size];
int cur[size];
double exc[size];

void relabel(int v) {
	int mn = 2 * n + 10;
	for (int i = 0; i < (int) vertex[v].size(); i++)
		if (vertex[v][i].cap > vertex[v][i].flow + eps) {
			mn = min(mn, hg[vertex[v][i].tg] + 1);
		}

	hg[v] = mn;
	cur[v] = 0;
}

queue <int> q;

void discharge(int v) {
	while (exc[v] > eps) {
		while (cur[v] < (int) vertex[v].size() && exc[v] > eps) {
			if (hg[vertex[v][cur[v]].tg] != hg[v] - 1 || vertex[v][cur[v]].cap < vertex[v][cur[v]].flow + eps) {
				cur[v]++;
				continue;
			}

			double d = min(exc[v], vertex[v][cur[v]].cap - vertex[v][cur[v]].flow);
			vertex[v][cur[v]].flow += d;
			vertex[vertex[v][cur[v]].tg][vertex[v][cur[v]].back].flow -= d;
			exc[v] -= d;
			if (exc[vertex[v][cur[v]].tg] < eps) {
				if (vertex[v][cur[v]].tg != str && vertex[v][cur[v]].tg != fin) {
					q.push(vertex[v][cur[v]].tg);
				}
			}
			exc[vertex[v][cur[v]].tg] += d;
		}
		if (exc[v] > eps)
			relabel(v);
	}
}

double maxflow(int str, int fin) {
	for (int i = 0; i < n + 2; i++) {
		hg[i] = 0;
		exc[i] = 0.0;
		cur[i] = 0;
	}
	hg[str] = n + 2;

	for (int i = 0; i < (int) vertex[str].size(); i++) {
		if (vertex[str][i].cap < vertex[str][i].flow + eps)
			continue;
		exc[vertex[str][i].tg] = vertex[str][i].cap - vertex[str][i].flow;
		vertex[str][i].flow = vertex[str][i].cap;
		vertex[vertex[str][i].tg][vertex[str][i].back].flow = - vertex[str][i].cap;
		q.push(vertex[str][i].tg);
	}

	while (!q.empty()) {
		int v = q.front();
		q.pop();
		discharge(v);
	}

	return exc[fin];
}

bool check(double lamb) {
	for (int i = 0; i < n + 2; i++) {
		for (int j = 0; j < (int) vertex[i].size(); j++)
			vertex[i][j].flow = 0.0;
	}
	for (int i = 0; i < (int) vertex[str].size(); i++)
		vertex[str][i].cap = 2 * lamb;

	return maxflow(str, fin) < sumdeg - eps2;
}

int main() {
	//assert(freopen("input.txt", "r", stdin));
	//assert(freopen("output.txt", "w", stdout));

	scanf("%d", &tc);
	for (int tnum = 0; tnum < tc; tnum++) {
		scanf("%d", &n);
		for (int i = 0; i < n; i++) {
			scanf("%d", &p[i]);
		}

		str = 0;
		fin = n + 1;
		for (int i = 0; i < n + 2; i++)
			vertex[i].clear();
		for (int i = 0; i < n; i++)
			deg[i] = 0;
		sumdeg = 0;
		for (int i = 0; i < n; i++)
			for (int j = i + 1; j < n; j++) 
				if (p[i] > p[j]) {
					addedge(i + 1, j + 1, 1, 1);
					deg[i]++;
					deg[j]++;
					sumdeg += 2;
				}
		for (int i = 0; i < n; i++)
			addedge(i + 1, fin, deg[i], 0);
		for (int i = 0; i < n; i++)
			addedge(str, i + 1, 0, 0);

		double lb = 0.0;
		double rb = n;
		while (rb - lb > 1e-7) {
			double mid = (lb + rb) / 2.0;
			if (check(mid))
				lb = mid;
			else
				rb = mid;
		}

		printf("Case #%d: %.10lf\n", tnum + 1, (lb + rb) / 2.0);
	}

	return 0;
}