#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <ctime>
#include <cstring>
#include <algorithm>
#include <iostream>
#include <set>
#include <map>
#include <vector>
#include <queue>
#include <deque>
using namespace std;
#define pb push_back
#define mp make_pair
#define sc second
#define fs first
#define int64 long long
#define ldb long double
#define sz(a) ((int) (a).size())
#define eprintf(...) fprintf(stderr, __VA_ARGS__)

const double pi = acos(-1.0);
const int size = 3000;
const double eps = 1e-8;

inline double sqr(double x) {
	return x * x;
}

struct point {
	double x, y;
	point(double x_ = 0.0, double y_ = 0.0) : x(x_), y(y_) {}
	void norm() {
		double k = sqrt(sqr(x) + sqr(y));
		x /= k;
		y /= k;
	}

	void read() {
		scanf("%lf%lf", &x, &y);
	}

	double dist(const point& p) const {
		return sqrt(sqr(p.x - x) + sqr(p.y - y));
	}
};

point operator - (const point& a, const point& b) {
	return point(a.x - b.x, a.y - b.y);
}

point operator + (const point& a, const point& b) {
	return point(a.x + b.x, a.y + b.y);
}

point operator * (const point& a, double k) {
	return point(a.x * k, a.y * k);
}

inline double vmult(double a, double b, double c, double d) {
	return a * d - b * c;
}

double smult(const point& a, const point& b) {
	return a.x * b.x + a.y * b.y;
}

int sign(double x) {
	if (fabs(x) < eps)
		return 0;
	if (x < 0)
		return -1;
	return 1;
}

inline double vmult(const point& a, const point& b) {
	return a.x * b.y - a.y * b.x;
}

int tc;
int n, m;
double tet, rad;
bool ans[size];
point pts[size];

bool onseg(const point& a, const point& b, const point& p) {
	return a.dist(p) + b.dist(p) < a.dist(b) + eps; 
}

point rotate(const point& p, double ang) {
	double ta = atan2(p.y, p.x);
	ta += ang;

	return point(cos(ta), sin(ta));
}

void applyparrallel(const point& p1, point v1, point v2) {
	if (sign(vmult(v1, v2)) == 0) {
		/*point p2 = p1 + v1 + v2;
		for (int i = 0; i < n; i++)
			if (!ans[i] && onseg(p1, p2, pts[i])) {
				ans[i] = true;
			}
		*/
		return;
	}
	if (sign(vmult(v1, v2)) < 0)
		swap(v1, v2);
	for (int i = 0; i < n; i++) {
		if (!ans[i]) {
			if (sign(vmult(pts[i] - p1, v1)) <= 0 && sign(vmult(pts[i] - p1, v2)) >= 0) {
				point h = pts[i] - (p1 + v1 + v2);
				if (sign(vmult(h, v2)) <= 0 && sign(vmult(h, v1)) >= 0)
					ans[i] = true;
			}
		}
	}
}

void applyangle(const point& cen, const point& vec, double ang, double rad) {
	double cs = cos(ang);
	for (int i = 0; i < n; i++) {
		if (!ans[i]) {
			double rd = cen.dist(pts[i]);
			if (rd > rad + eps)
				continue;
			if (ang > pi - eps) {
				ans[i] = true;
				continue;
			}
			double sm = smult(pts[i] - cen, vec) / rd;
			if (sm > cs - eps) {
				ans[i] = true;
			}
		}
	}
}

int main() {
	//assert(freopen("input.txt", "r", stdin));
	//assert(freopen("output.txt", "w", stdout));

	scanf("%d", &tc);
	for (int tnum = 0; tnum < tc; tnum++) {
		scanf("%d%d%lf%lf", &n, &m, &tet, &rad);
		tet /= 180.0;
		tet *= pi;

		for (int i = 0; i < n; i++)
			ans[i] = false;
		point st, lookv, movev;
		st.read();
		lookv.read();
		lookv.norm();
		movev.read();
		movev.norm();

		for (int i = 0; i < n; i++)
			pts[i].read();

		applyangle(st, lookv, tet / 2.0, rad);
		double curt = 0.0;

		for (int i = 0; i < m; i++) {
			int tp;
			double t, a;
			scanf("%d%lf%lf", &tp, &t, &a);
			a /= 180.0;
			a *= pi;

			double shift = t - curt;
			point way = movev * shift;

			point lb = rotate(lookv, -tet / 2.0);
			point rb = rotate(lookv, tet / 2.0);

			applyparrallel(st, way, lb * rad);
			applyparrallel(st, way, rb * rad);

			point ort(-movev.y, movev.x);

			if (smult(lookv, ort) > cos(tet / 2.0) - eps) {
				applyparrallel(st, way, ort * rad);
			}
			ort = ort * -1;
			if (smult(lookv, ort) > cos(tet / 2.0) - eps) {
				applyparrallel(st, way, ort * rad);
			}

			st = st + way;
			applyangle(st, lookv, tet / 2.0, rad);

			curt = t;
			if (tp == 1) {
				point h = rotate(lookv, - a / 2.0);
				applyangle(st, h, tet / 2.0 + a / 2.0, rad);
				lookv = rotate(lookv, - a);
			} else {
				movev = rotate(movev, -a);
			}
		}

		printf("Case #%d: ", tnum + 1);
		for (int i = 0; i < n; i++)
			if (ans[i])
				printf("0");
			else
				printf("1");
		printf("\n");
	}

	return 0;
}