#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <ctime>
#include <cstring>
#include <cassert>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <stack>
#include <queue>
#include <deque>
#include <complex>

using namespace std;

#define pb push_back
#define mp make_pair
#define sz(s) int((s).size())
#define len(s) int((s).size())
#define all(s) (s).begin(), (s).end()
#ifdef _WIN32
#define LLD "%I64d"
#else
#define LLD "%lld"
#endif
#ifdef LOCAL42
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
#else
#define eprintf(...) 42
#endif
#define y0 yy0
#define y1 yy1
#define next _next
#define prev _prev
#define rank _rank
#define link _link
#define hash _hash
#define fs first
#define sc second

typedef long long ll;
typedef long long llong;
typedef long long int64;
typedef unsigned int uint;
typedef long double ld;
typedef unsigned long long ull;
typedef unsigned long long ullong;
typedef unsigned long long lint;
typedef pair<int, int> pii;
typedef vector<int> vi;

const int inf = int(1e9);
const double eps = 1e-9;
const double pi = 4 * atan(double(1));
const int N = 1010;

inline double sqr(double x) {
	return x * x;
}

struct point {

	double x, y;
	
	point() {}

	point(double x, double y) {
		this->x = x;
		this->y = y;
	}

	inline void norm(double len) {
		double d = sqrt(sqr(x) + sqr(y));
		x *= len / d;
		y *= len / d;
	}

	inline void rot(double ang) {
		double nx = x * cos(ang) - y * sin(ang);
		double ny = x * sin(ang) + y * cos(ang);
		x = nx;
		y = ny;
	}

};

struct line {

	double a, b, c;

	line() {}

	line(point A, point B) {
		a = A.y - B.y;
		b = B.x - A.x;
		c = -a * A.x - b * A.y;
	}

	inline double dist(point p) {
		return a * p.x + b * p.y + c;
	}

	inline void norm() {
		double d = sqrt(sqr(a) + sqr(b));
		a /= d;
		b /= d;
		c /= d;
	}

	inline void move(double len) {
		c += len;
	}

};

point operator * (const point &a, double b) {
	return point(a.x * b, a.y * b);
}

point operator + (const point &a, const point &b) {
	return point(a.x + b.x, a.y + b.y);
}

point operator - (const point &a, const point &b) {
	return point(a.x - b.x, a.y - b.y);
}

struct event {

	int tp;
	point p, d, v;
	double ang, t;

	event(point p, point v, double ang) {
		tp = 0;
		this->p = p;
		this->v = v;
		this->ang = ang;
	}

	event(point p, point d, point v, double t) {
		tp = 1;
		this->p = p;
		this->d = d;
		this->v = v;
		this->t = t;
	}

};

int n;
double R, view_ang;
point a[N];
bool kill[N];
vector<event> events;

inline bool inside_circle(point p, double r, point cp) {
	return sqr(p.x - cp.x) + sqr(p.y - cp.y) < sqr(r) + eps;
}

inline bool inside_seg(point p, point v1, point v2, point cp) {
	line l(p, p + v1);
	if (l.dist(cp) < -eps) {
		return false;
	}
	l = line(p, p + v2);
	if (l.dist(cp) > eps) {
		return false;
	}
	return true;
}

inline bool inside_seg(point p, point v, point cp, double view_ang) {
	if (!inside_circle(p, R, cp)) {
		return false;
	}
	point v2 = v;
	v2.rot(-view_ang / 2);
	point v3 = v;
	v3.rot(view_ang / 2);
	return inside_seg(p, v2, v, cp) || inside_seg(p, v, v3, cp);
}

inline bool check_rotate(event e, point p) {
	point v = e.v;
	v.rot(e.ang / 2);
	return inside_seg(e.p, v, p, view_ang + fabs(e.ang));
}

vector<point> points;

inline void intersect_lines(line a, line b) {
	double d = a.a * b.b - a.b * b.a;
	if (fabs(d) < eps) {
		return;
	}
	points.pb(point((a.b * b.c - a.c * b.b) / d, (b.a * a.c - a.a * b.c) / d));
}

inline void intersect_line_circle(line l, point p, double r) {
	l.norm();
	if (fabs(l.dist(p)) > r + eps) {
		return;
	}
	double d = sqrt(max(sqr(r) - sqr(l.dist(p)), 0.0));
	line l2;
	l2.a = -l.b;
	l2.b = l.a;
	l2.c = -l2.a * p.x - l2.b * p.y;
	l2.move(-d);
	intersect_lines(l, l2);
	l2.move(2 * d);
	intersect_lines(l, l2);
}

inline bool in_line(line l, point p) {
	return fabs(l.dist(p)) < eps;
}

inline double scal(point a, point b) {
	return a.x * b.x + a.y * b.y;
}

inline bool check_move(event e, point p) {
	if (inside_seg(e.p, e.v, p, view_ang)) {
		return true;
	}
	points.clear();
	line l(p, p + e.d);
	intersect_line_circle(l, e.p, R);
	if (in_line(l, e.p)) {
		points.pb(e.p);
	}
	point v = e.v;
	v.rot(-view_ang / 2);
	v.norm(R);
	if (in_line(l, e.p + v)) {
		points.pb(e.p + v);
	}
	intersect_lines(l, line(e.p, e.p + v));
	v.rot(view_ang);
	if (in_line(l, e.p + v)) {
		points.pb(e.p + v);
	}
	intersect_lines(l, line(e.p, e.p + v));
	for (int i = 0; i < sz(points); ++i) {
		if (!inside_seg(e.p, e.v, points[i], view_ang)) {
			continue;
		}
		point vec = p - points[i];
		double len = scal(vec, e.d);
		if (len < -eps) {
			continue;
		}
		if (len > e.t + eps) {
			continue;
		}
		return true;
	}
	return false;
}

inline void process_event(event e) {
	for (int i = 0; i < n; ++i) {
		if (kill[i]) {
			continue;
		}
		if (e.tp == 0) {
			if (check_rotate(e, a[i])) {
				kill[i] = true;
			}
		} else {
			if (check_move(e, a[i])) {
				kill[i] = true;
			}
		}
	}
}

inline void solve() {
	int m;
	scanf("%d %d %lf %lf", &n, &m, &view_ang, &R);
	view_ang = view_ang / 180 * pi;
	point cp;
	scanf("%lf %lf", &cp.x, &cp.y);
	point v;
	scanf("%lf %lf", &v.x, &v.y);
	point d;
	scanf("%lf %lf", &d.x, &d.y);
	d.norm(1);
	v.norm(1);
	for (int i = 0; i < n; ++i) {
		scanf("%lf %lf", &a[i].x, &a[i].y);
	}
	events.clear();
	events.pb(event(cp, v, 0));
	double last_t = 0;
	for (int i = 0; i < m; ++i) {
		int p;
		double t, ang;
		scanf("%d %lf %lf", &p, &t, &ang);
		ang = -ang / 180 * pi;
		events.pb(event(cp, d, v, t - last_t));
		cp = cp + d * (t - last_t);
		last_t = t;
		if (p == 2) {
			d.rot(ang);
		} else {
			events.pb(event(cp, v, ang));
			v.rot(ang);
		}
	}
	for (int i = 0; i < n; ++i) {
		kill[i] = false;
	}
	for (int i = 0; i < sz(events); ++i) {
		process_event(events[i]);
	}
	for (int i = 0; i < n; ++i) {
		if (kill[i]) {
			printf("0");
		} else {
			printf("1");
		}
	}
	puts("");
}

int main() {
#ifdef LOCAL42
#define TASK "E"
	freopen(TASK ".in", "r", stdin);
	freopen(TASK ".out", "w", stdout);
#else

#endif
	int t;
	scanf("%d", &t);
	for (int i = 0; i < t; ++i) {
		printf("Case #%d: ", i + 1);
		solve();
	}
	return 0;
}
