#include <stdio.h>
#include <math.h>
#include <string.h>
#include <memory.h>
#include <stdlib.h>
#include <ctype.h>
#include <vector>
#include <string>
#include <map>
#include <set>
#include <algorithm>
#include <iostream>
using namespace std;
typedef long long LL;
typedef pair<int, int> pii;
typedef vector<int> vint;
typedef vector<string> vstr;
#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=a;i--)
#define ALL(v) v.begin(),v.end()
const int INF = 0x7FFFFFFF;
const double PI = 3.1415926535897932384626433832795;

const double EPS = 1e-8;

inline double sqr(double x) {
  return x * x;
}

struct Vector {
  double x, y;
  Vector() {}
  Vector(double x, double y) : x(x), y(y) {}

  double length2() {
    return x * x + y * y;
  }
  double length() {
    return sqrt(x * x + y * y);
  }
  Vector perp() {
    return Vector(-y, x);
  }
  Vector& normalize() {
    double len = sqrt(x * x + y * y);
    x /= len; y /= len;
    return *this;
  }

  Vector& operator += (Vector const& v) {
    x += v.x; y += v.y;
    return *this;
  }
  Vector& operator -= (Vector const& v) {
    x -= v.x; y -= v.y;
    return *this;
  }
  Vector& operator *= (double f) {
    x *= f; y *= f;
    return *this;
  }
  Vector& operator /= (double f) {
    x /= f; y /= f;
    return *this;
  }
};
Vector operator + (Vector const& a, Vector const& b) {
  return Vector(a.x + b.x, a.y + b.y);
}
Vector operator - (Vector const& a, Vector const& b) {
  return Vector(a.x - b.x, a.y - b.y);
}
Vector operator - (Vector const& a) {
  return Vector(-a.x, -a.y);
}
Vector operator * (Vector const& a, Vector const& b) {
  return Vector(a.x * b.x, a.y * b.y);
}
Vector operator * (Vector const& a, double f) {
  return Vector(a.x * f, a.y * f);
}
Vector operator * (double f, Vector const& a) {
  return Vector(a.x * f, a.y * f);
}
Vector operator / (Vector const& a, double f) {
  return Vector(a.x / f, a.y / f);
}
double dot(Vector const& a, Vector const& b) {
  return a.x * b.x + a.y * b.y;
}
double cross(Vector const& a, Vector const& b) {
  return a.x * b.y - a.y * b.x;
}

bool operator < (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x < b.x;
  return a.y < b.y - EPS;
}
bool operator <= (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x < b.x;
  return a.y <= b.y + EPS;
}
bool operator > (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x > b.x;
  return a.y > b.y + EPS;
}
bool operator >= (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x > b.x;
  return a.y >= b.y - EPS;
}
bool operator == (Vector const& a, Vector const& b) {
  return fabs(a.x - b.x) < EPS && fabs(a.y - b.y) < EPS;
}
bool operator != (Vector const& a, Vector const& b) {
  return fabs(a.x - b.x) >= EPS || fabs(a.y - b.y) >= EPS;
}

typedef Vector Point;

double ConeAngle;
double ConeCos, ConeSin;
double ConeRadius;
double LookDir;
double VelocityDir;
Vector initLookVector;
Vector lookVector;
Vector initVelocity;
Point position;
Vector velocity;

Vector lookLeft(Vector look) {
  return Vector(look.x * ConeCos - look.y * ConeSin,
                look.x * ConeSin + look.y * ConeCos);
}
Vector lookRight(Vector look) {
  return Vector(look.x * ConeCos + look.y * ConeSin,
               -look.x * ConeSin + look.y * ConeCos);
}

void turnLook(double delta) {
  LookDir += delta;
  while (LookDir > 2 * PI) LookDir -= 2 * PI;
  while (LookDir < 0) LookDir += 2 * PI;
  double cs = cos(LookDir);
  double sn = sin(LookDir);
  lookVector.x = initLookVector.x * cs - initLookVector.y * sn;
  lookVector.y = initLookVector.x * sn + initLookVector.y * cs;
}
void turnVelocity(double delta) {
  VelocityDir += delta;
  double cs = cos(VelocityDir);
  double sn = sin(VelocityDir);
  velocity.x = initVelocity.x * cs - initVelocity.y * sn;
  velocity.y = initVelocity.x * sn + initVelocity.y * cs;
}

bool inCone(Point a, Point c, Vector look) {
  a -= c;
  double dist = a.length();
  if (dist > ConeRadius + EPS) return false;
  if (dist < EPS) return true;
  a /= dist;
  return dot(look, a) > ConeCos - EPS;
}
bool inPara(Point x, Point a, Point b, Vector d) {
  a -= b;
  x -= b;
  double cp = cross(a, d);
  double t1 = -cross(x, d) / cp;
  if (t1 < -1 - EPS || t1 > EPS) return false;
  double t2 = cross(x, a) / cp;
  if (t2 < -1 - EPS || t2 > EPS) return false;
  return true;
}
bool inTurn(Point a, Point c, double a0, double da) {
  a -= c;
  double dist = a.length();
  if (dist > ConeRadius + EPS) return false;
  if (dist < EPS) return true;
  a /= dist;
  if (da < 0) a0 += da, da = -da;
  a0 -= ConeAngle;
  da += 2 * ConeAngle;
  double a1 = atan2(a.y, a.x);
  if (a1 > a0 - EPS && a1 < a0 + da + EPS) return true;
  if (a1 + 2 * PI > a0 - EPS && a1 + 2 * PI < a0 + da + EPS) return true;
  if (a1 - 2 * PI > a0 - EPS && a1 - 2 * PI < a0 + da + EPS) return true;
  if (a1 + 4 * PI > a0 - EPS && a1 + 4 * PI < a0 + da + EPS) return true;
  if (a1 - 4 * PI > a0 - EPS && a1 - 4 * PI < a0 + da + EPS) return true;
  return false;
}

bool canSee(Point x, Point a, Point b, Vector look) {
  if (inCone(x, a, look)) return true;
  if (inCone(x, b, look)) return true;
  Vector d = b - a;
  double len = d.length();
  if (len < EPS) {
    return false;
  }
  d /= len;
  Vector d1 = d.perp();
  Vector d2 = -d1;
  Vector left = lookLeft(look);
  Vector right = lookRight(look);
  if (dot(look, d1) < ConeCos) {
    Vector od1 = d1;
    d1 = Vector(0, 0);
    if (dot(od1, left) > dot(od1, d1)) d1 = left;
    if (dot(od1, right) > dot(od1, d1)) d1 = right;
  }
  if (dot(look, d2) < ConeCos) {
    Vector od2 = d2;
    d2 = Vector(0, 0);
    if (dot(od2, left) > dot(od2, d2)) d2 = left;
    if (dot(od2, right) > dot(od2, d2)) d2 = right;
  }
  d1 *= ConeRadius;
  d2 *= ConeRadius;
  return inPara(x, a + d1, a + d2, b - a);
}


void test(int T) {
  int n, m;
  cin >> n >> m >> ConeAngle >> ConeRadius;
  ConeAngle = (ConeAngle * PI / 180) / 2;
  ConeCos = cos(ConeAngle);
  ConeSin = sin(ConeAngle);
  LookDir = 0;
  VelocityDir = 0;
  cin >> position.x >> position.y >> initLookVector.x >> initLookVector.y >> velocity.x >> velocity.y;
  initLookVector.normalize();
  velocity.normalize();
  initVelocity = velocity;
  lookVector = initLookVector;

  vector<Point> big(n);
  vector<pair<pair<Point, Point>, Vector>> brush;
  vector<pair<Point, pair<double, double>>> turns;
  FOR(i, 0, n) cin >> big[i].x >> big[i].y;
  double lastTime = 0;
  FOR(i, 0, m) {
    int type; double curTime, dAngle;
    cin >> type >> curTime >> dAngle;
    dAngle *= PI / 180;
    brush.push_back(make_pair(make_pair(position, position + (curTime - lastTime) * velocity), lookVector));
    position += (curTime - lastTime) * velocity;
    if (type == 1) {
      double aInitial = atan2(initLookVector.y, initLookVector.x);
      turns.push_back(make_pair(position, make_pair(aInitial + LookDir, -dAngle)));
    }
    lastTime = curTime;
    if (type == 1) {
      turnLook(-dAngle);
    } else {
      turnVelocity(-dAngle);
    }
  }

  cout << "Case #" << T + 1 << ": ";
  FOR(i, 0, n) {
    bool ok = true;
    FOR(j, 0, m) {
      if (canSee(big[i], brush[j].first.first, brush[j].first.second, brush[j].second)) {
        ok = false;
      }
    }
    for (auto& t : turns) {
      if (inTurn(big[i], t.first, t.second.first, t.second.second)) {
        ok = false;
      }
    }
    cout << (ok ? "1" : "0");
  }
  cout << "\n";
}

int main() {
  int T;
  cin >> T;
  FOR(i, 0, T) test(i);
  return 0;
}
