#include <iostream>
#include <cstdio>
#include <unordered_set>
#include <tuple>
#include <cmath>
#include <sstream>
#include <vector>

using namespace std;

typedef uint32_t U;

struct Block {
	U addr;
	int len;
};

istream& operator>>(istream& in, Block& block) {
	string S;
	in >> S;
	
	block.addr = 0;
	int i = 0;
	int j = 0;
	for(int x = 0; x < 4; ++x) {
		block.addr <<= 8;
		while(S[j] != '.' && S[j] != '/') ++j;
		
		stringstream ss(S.substr(i, j - i) + "\n");
		U sd;
		ss >> sd;
		block.addr |= sd;
		
		i = j + 1;
		j = i;
	}
	
	stringstream ss(S.substr(i, S.size() - i) + "\n");
	ss >> block.len;
	
	return in;
}
ostream& operator<<(ostream& out, Block block) {
	for(int x = 0; x < 4; ++x) {
		U sd = (block.addr >> (8 * (3 - x))) & 255u;
		out << sd;
		if(x == 3) {
			out << '/';
		} else {
			out << '.';
		}
	}
	out << block.len;
	
	return out;
}

typedef pair<int, int> Node;
vector<Node> trie;

vector<Block> out;
void dfs(int v, Block block) {
	if(trie[v].first == -2) return;
	
	if(trie[v].first == -1 && trie[v].second == -1) {
		out.push_back(block);
		return;
	}
	
	Block left = block;
	++left.len;
	if(trie[v].first == -1) {
		out.push_back(left);
	} else {
		dfs(trie[v].first, left);
	}
	
	Block right = block;
	++right.len;
	right.addr |= (U)1 << (32 - right.len);
	if(trie[v].second == -1) {
		out.push_back(right);
	} else {
		dfs(trie[v].second, right);
	}
}

int main() {
	cin.sync_with_stdio(false);
	
	int Te;
	cin >> Te;
		
	for(int te = 0; te < Te; ++te) {
		trie.clear();
		trie.emplace_back(-1, -1);
		
		int n;
		cin >> n;
		
		for(int i = 0; i < n; ++i) {
			Block block;
			cin >> block;
			
			int v = 0;
			for(int i = 0; i < block.len; ++i) {
				if(trie[v].first == -2) break;
				
				int bit = (block.addr >> (31 - i)) & 1;
				if(!bit) {
					if(trie[v].first == -1) {
						trie[v].first = trie.size();
						trie.emplace_back(-1, -1);
					}
					v = trie[v].first;
				} else {
					if(trie[v].second == -1) {
						trie[v].second = trie.size();
						trie.emplace_back(-1, -1);
					}
					v = trie[v].second;
				}
			}
			trie[v].first = -2;
		}
		
		Block block;
		block.addr = 0;
		block.len = 0;
		out.clear();
		dfs(0, block);
		
		cout << "Case #" << te + 1 << ":\n" << out.size() << "\n";
		for(Block block : out) {
			cout << block << "\n";
		}
	}
	
	return 0;
}
