#include <iostream>
#include <algorithm>
#include <set>
#include <map>
#include <string>
#include <cstring>
#include <cstdio>
#include <ctime>
#include <cassert>
#include <vector>
#include <queue>
#include <cmath>

#define fr first
#define sc second
#define mp make_pair
#define pb push_back 

using namespace std;

const int N = 1e5;
const int INF = 1e9;

struct Edge {
	int to, flow, cap;	
	Edge() { }
	Edge(int to, int flow, int cap): to(to), flow(flow), cap(cap) { }
};

vector < pair < int, int > > edge;
vector < pair < int, int > > frac;
Edge data[N];
int cur;
int c[N];
int dist[N];
int a[N];
vector < int > e[N];
queue < int > q;
int n, m, S, F;

int gcd(int a, int b) {
	return (b == 0)? a: gcd(b, a % b);
}

void addEdge(int from, int to, int cap) {
	data[cur] = Edge(to, 0, cap);
	data[cur + 1] = Edge(from, 0, 0);
	e[from].pb(cur);
	e[to].pb(cur + 1);
	cur += 2;
}

bool bfs() {
	memset(dist, 63, sizeof(dist));
	dist[S] = 0;
	q.push(S);
	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (auto x: e[v]) {
			int u = data[x].to;
			if (dist[u] > dist[v] + 1 && data[x].flow < data[x].cap) {
				dist[u] = dist[v] + 1;
				q.push(u);
			}
		}
	}
	return dist[F] < INF;
}

int dfs(int v, int f) {
	if (v == F) return f;	
	for (; c[v] < (int)e[v].size(); c[v]++) {
		int x = e[v][c[v]];
		if (data[x].flow < data[x].cap && dist[data[x].to] > dist[v]) {
			int r = dfs(data[x].to, min(f, data[x].cap - data[x].flow));
			if (r > 0) {
				data[x].flow += r;
				data[x ^ 1].flow -= r;
				return r;
			}
		}
	}
	return 0;
}

bool check(pair < int, int > pr) {
	int p = pr.fr;
	int q = pr.sc;
	S = n + m;
	F = n + m + 1;
	for (int i = 0; i < n + m + 2; i++)
		e[i].clear();
	cur = 0;
	for (int i = 0; i < n; i++)
		addEdge(i, F, p);
	for (int i = 0; i < m; i++)
		addEdge(S, i + n, q);
	for (int i = 0; i < m; i++) {
		addEdge(i + n, edge[i].fr, INF);
		addEdge(i + n, edge[i].sc, INF);
	}
	int sum = m * q;
	int flow = 0;
	//cerr << "p q: " << p << " " << q << endl;
	for (;bfs();) {
		for (int i = 0; i < n + m + 2; i++)
			c[i] = 0;
		for (;;) {
			//cerr << "sdf\n";
			int d = dfs(S, INF);
			if (d == 0) break;
			flow += d;
		}
	}
	return sum - flow > 0;
}

bool cmpF(pair < int, int > a, pair < int, int > b) {
	return a.fr * b.sc < a.sc * b.fr;
}

int main() {
#ifdef DEBUG
	freopen("in", "r", stdin);
#endif
	int T;
	scanf("%d", &T);
	for (int tt = 0; tt < T; tt++) {
		scanf("%d", &n);
		for (int i = 0; i < n; i++)
			scanf("%d", &a[i]);
		edge.clear();
		for (int i = 0; i < n; i++)
			for (int j = i + 1; j < n; j++)  	
				if (a[i] > a[j])
					edge.pb(mp(i, j));
		m = edge.size();	
		printf("Case #%d: ", tt + 1);	
		if (m == 0) {
			printf("0.0\n");
			continue;
		}
		frac.clear();
		for (int i = 0; i <= m; i++)
			for (int j = 1; j <= n; j++)
				frac.pb(mp(i, j));
		for (auto & x: frac) {
			int d = gcd(x.fr, x.sc);
			x.fr /= d;
			x.sc /= d;
		}
		sort(frac.begin(), frac.end(), cmpF);
		frac.resize(unique(frac.begin(), frac.end()) - frac.begin());

		//for (auto x: frac)
			//cerr << x.fr << " " << x.sc << endl;

		vector < pair < int, int > > tmp;	
		for (int i = 0; i < (int)frac.size() - 1; i++)
			tmp.pb(mp(frac[i].fr + frac[i + 1].fr, frac[i].sc + frac[i + 1].sc));
		
		//cerr << endl;
		////for (auto x: tmp)
			//cerr << x.fr << " " << x.sc << endl;


		swap(tmp, frac);
		int l = 0;
		int r = frac.size();	

		while (r - l > 1) {
			if (check(frac[(l + r) / 2]))
				l = (l + r) / 2;
			else
				r = (l + r) / 2;
		}
		printf("%.15lf\n", tmp[l + 1].fr * 1.0 / tmp[l + 1].sc);
	}
	return 0;
}

