#include <iostream>
#include <fstream>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <iomanip>
#include <algorithm>
#include <queue>

#define DBG_

typedef long long ll;
typedef long double ld;

using namespace std;

struct TreeNode {
	TreeNode *l, *r, *parent;
	bool killChildren;
};

TreeNode root;

void addToTree(ll prefix, ll len) {
	TreeNode *tn = &root;
	for (ll i = 0; i < len; ++i) {
		bool left = ((prefix & (1LL << (31LL - i))) == 0);
		if (left) {
			if (tn->l == NULL) {
#ifdef DBG
				cout << "Added left node" << endl;
#endif
				tn->l = new TreeNode;
				tn->l->parent = tn;
				tn->l->l = tn->l->r = NULL;
				tn->l->killChildren = false;
			}
			tn = tn->l;
		} else {
			if (tn->r == NULL) {
#ifdef DBG
				cout << "Added right node" << endl;
#endif
				tn->r = new TreeNode;
				tn->r->parent = tn;
				tn->r->l = tn->r->r = NULL;
				tn->r->killChildren = false;
			}
			tn = tn->r;
		}
	}

	//cout << "node that was rightmost for subnet: " << tn << endl;
	tn->killChildren = true;
	
#ifdef DBG
	cout << "ADD TO TREE " << prefix << " " << len << " -> " << tn << " W parent " << tn->parent << endl;
#endif
}

int n;
//bool treeWasAlreadyConstructedSoIfItIsEmptyThatMeansThereIsNoComplement_exclamation_mark;

void readSub() {
	ll prefix = 0;
	ll len;
	char sep;
	for (ll i = 0; i < 4; ++i) {
		cin >> len;
		prefix |= (len << (24LL - (i << 3LL)));
		cin >> sep;
	}
	cin >> len;

#ifdef DBG
	cout << "read prefix is " << prefix << "=0" << endl;
#endif

	addToTree(prefix, len);
	//treeWasAlreadyConstructedSoIfItIsEmptyThatMeansThereIsNoComplement_exclamation_mark = true;
}

void reduceTree(TreeNode *node) {
	if (node == NULL)
		return;

	if (node->killChildren) {
#ifdef DBG
		cout << "Found node that kills children: " << node << endl;
#endif
		node->l = node->r = NULL;
		return;
	}

	reduceTree(node->l);
	reduceTree(node->r);

	if (node->l != node->r) // this node still has child(ren)
		return;

	// if brother is childless, we can reduce to parent node without losing prefix data
	if (node->parent == NULL)
		return; // nothing to reduce to

	TreeNode *bro;
	if (node->parent->l == node)
		bro = node->parent->r;
	else
		bro = node->parent->l;

	if (bro == NULL || bro->l != NULL || bro->r != NULL)
		return;

	// reduce to parent
	node->parent->l = node->parent->r = NULL;
	node->parent->killChildren = true;
}

void printSub(ll prefix, ll len) {
	for (int i = 0; i < 4; ++i) {
		cout << ((prefix >> (24LL - (i << 3LL))) & 0xFF) << (i == 3 ? '/' : '.');
	}
	cout << len << endl;
}

vector<pair<ll, ll> > complements;

void makeComp(TreeNode *node, ll cp, ll cl) {
	if (node == NULL)
		return;

	makeComp(node->l, cp, cl + 1);
	makeComp(node->r, cp | (1LL << (31LL - cl)), cl + 1);

	if (node->l != NULL && node->r != NULL) {
#ifdef DBG
		cout << "Node has both children: " << node << endl;
#endif
		return; // do NOTHING at this point, both parts of the prefix are present
	}

	if (node->l == NULL && node->r == NULL) {
#ifdef DBG
		cout << "Leaf: " << node << endl;
#endif
		// this is a leaf. do nothing unless it is the root of everything
		if (n == 0)
			complements.push_back(make_pair(0, 0));
		//if (node->parent == NULL && !node->killChildren/* && !treeWasAlreadyConstructedSoIfItIsEmptyThatMeansThereIsNoComplement_exclamation_mark*/)
		//	complements.push_back(make_pair(0, 0));
		return;
	}
	
#ifdef DBG
	cout << "Parent with a single child: " << node << endl;
#endif

	// otherwise, insert prefix of the missing child
	//cout << "Found missing child. Current prefix is " << cp << ", prefix len: " << cl << endl;
	ll result = cp; // if left child, the prefix is OK as is
	if (node->r == NULL) {
		ll flipIdx = 31LL - cl;
		result |= (1LL << flipIdx);
		//cout << "Setting bit at " << flipIdx << ", result: " << result << endl;
	}
	complements.push_back(make_pair(result, cl + 1));

	/*
	cout << "Found missing child. Current prefix is " << cp << ", prefix len: " << cl << endl;
	ll flipIdx = 31 - cl;
	cout << "Flipping bit at " << flipIdx << ", result: " << (cp ^ (1LL << flipIdx)) << endl;
	complements.push_back(make_pair(cp ^ (1LL << flipIdx), cl + 1));
	*/
}

#ifdef DBG
void printTree(TreeNode *node, int depth) {
	if (node == NULL)
		return;

	cout << node << " @ " << depth << endl;
	printTree(node->l, depth + 1);
	printTree(node->r, depth + 1);
}
#endif

int main() {
	//freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);

	int T;
	cin >> T;

	for (int t = 1; t <= T; ++t) {
		cout << "Case #" << t << ':' << endl;
		
		root.l = root.r = root.parent = NULL;
		root.killChildren = false;
		//treeWasAlreadyConstructedSoIfItIsEmptyThatMeansThereIsNoComplement_exclamation_mark = false;
		complements.clear();
		cin >> n;
		for (int i = 0; i < n; ++i) {
			readSub();
		}

#ifdef DBG
		cout << "Input:" << endl;
		printTree(&root, 0);
#endif
		reduceTree(&root);
#ifdef DBG
		cout << "Fixed:" << endl;
		printTree(&root, 0);
#endif

		makeComp(&root, 0, 0);

		cout << complements.size() << endl;
		for (vector<pair<ll, ll> >::iterator it = complements.begin(); it != complements.end(); ++it) {
			printSub(it->first, it->second);
		}
	}

	return 0;
}
