#include <iostream>
#include <vector>

using namespace std;

struct Trie {
    Trie(): left(nullptr), right(nullptr), bad(false) {}
    Trie *left, *right;
    bool bad;
};

template<class I>
void insert(Trie* node, I begin, I end) {
    for (auto x = begin; x != end; ++x) {
        char c = *x;
        if (c == '0' && !node->left)
            node->left = new Trie;
        else if (c == '1' && !node->right)
            node->right = new Trie;
        if (c == '0')
            node = node->left;
        else
            node = node->right;
    }
    node->bad = true;
}

void solve(Trie* node, vector<string> &answer, const string &prefix = "") {
    if (node == nullptr) {
        answer.push_back(prefix);
        return;
    }

    if (node->bad)
        return;

    string next = prefix;
    next += '0';
    solve(node->left, answer, next);
    next.back() = '1';
    solve(node->right, answer, next);
}

string toBase2(string S) {
    string base2(32, ' ');

    int pos = 0;
    auto read = [&]() {
        while (S[pos] < '0' || S[pos] > '9')
            ++pos;
        int x = 0;
        while (pos < int(S.size()) && S[pos] >= '0' && S[pos] <= '9')
            x = x * 10 + S[pos++] - '0';
        return x;
    };

    for (int i = 0; i < 4; ++i) {
        int x = read();
        for (int j = 0; j < 8; ++j)
            base2[i * 8 + j] = (((1 << (7 - j)) & x) > 0) + '0';
    }

    int prefix = read();
    return base2.substr(0, prefix);
}

string toIP(string base2) {
    string padded = base2;
    padded.resize(32, '0');

    string ip;
    for (int i = 0; i < 4; ++i) {
        int x = 0;
        for (int j = 0; j < 8; ++j)
            x = x * 2 + padded[i * 8 + j] - '0';
        if (x > 99)
            ip += char(x / 100 + '0');
        x %= 100;
        if (x > 9)
            ip += char(x / 10 + '0');
        x %= 10;
        ip += char(x + '0');
        if (i < 3)
            ip += '.';
        else
            ip += '/';
    }
    int prefix = base2.size();
    if (prefix > 99)
        ip += char(prefix / 100 + '0');
    prefix %= 100;
    if (prefix > 9)
        ip += char(prefix / 10 + '0');
    prefix %= 10;
    ip += char(prefix + '0');
    return ip;
}

int main() {
    ios::sync_with_stdio(false);
    int T; cin >> T;

    for (int test = 1; test <= T; ++test) {
        int N; cin >> N;
        cout << "Case #" << test << ":\n";

        Trie *T = nullptr;
        if (N > 0)
            T = new Trie();
        for (int i = 0; i < N; ++i) {
            string S; cin >> S;
            string base2 = toBase2(S);
            insert(T, base2.begin(), base2.end());
        }

        vector<string> answer;
        solve(T, answer);

        cout << answer.size() << "\n";
        for (auto &x: answer) {
            cout << toIP(x) << "\n";
        }
    }
}
